# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/asset.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,systemathics/apis/type/shared/v1/asset.proto\x12 systemathics.apis.type.shared.v1\"^\n\x10\x41ssetTypeRequest\x12J\n\nasset_type\x18\x01 \x01(\x0e\x32+.systemathics.apis.type.shared.v1.AssetTypeR\tassetType*\xc6\x02\n\tAssetType\x12\x1a\n\x16\x41SSET_TYPE_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x41SSET_TYPE_ALL\x10\x01\x12\x15\n\x11\x41SSET_TYPE_EQUITY\x10\x02\x12\x15\n\x11\x41SSET_TYPE_FUTURE\x10\x03\x12\x12\n\x0e\x41SSET_TYPE_ETF\x10\x04\x12\x14\n\x10\x41SSET_TYPE_INDEX\x10\x05\x12\x14\n\x10\x41SSET_TYPE_FOREX\x10\x07\x12\x15\n\x11\x41SSET_TYPE_OPTION\x10\x08\x12\x13\n\x0f\x41SSET_TYPE_BOND\x10\t\x12\x12\n\x0e\x41SSET_TYPE_CDS\x10\n\x12\x18\n\x14\x41SSET_TYPE_CDS_INDEX\x10\x0b\x12 \n\x1c\x41SSET_TYPE_CDS_INDEX_TRANCHE\x10\x0c\x12\x1f\n\x1b\x41SSET_TYPE_CDS_INDEX_OPTION\x10\rB\xd7\x01\n$com.systemathics.apis.type.shared.v1B\nAssetProtoP\x01\xa2\x02\x04SATS\xaa\x02 Systemathics.Apis.Type.Shared.V1\xca\x02 Systemathics\\Apis\\Type\\Shared\\V1\xe2\x02,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\xea\x02$Systemathics::Apis::Type::Shared::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v1.asset_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.systemathics.apis.type.shared.v1B\nAssetProtoP\001\242\002\004SATS\252\002 Systemathics.Apis.Type.Shared.V1\312\002 Systemathics\\Apis\\Type\\Shared\\V1\342\002,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\352\002$Systemathics::Apis::Type::Shared::V1'
  _globals['_ASSETTYPE']._serialized_start=179
  _globals['_ASSETTYPE']._serialized_end=505
  _globals['_ASSETTYPEREQUEST']._serialized_start=82
  _globals['_ASSETTYPEREQUEST']._serialized_end=176
# @@protoc_insertion_point(module_scope)
