# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from systemathics.apis.services.tick.v2 import get_tick_scalar_pb2 as systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__scalar__pb2


class TickScalarServiceStub(object):
    """Called to request tick prices data. 
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.TickScalarStream = channel.unary_stream(
                '/systemathics.apis.services.tick.v2.TickScalarService/TickScalarStream',
                request_serializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__scalar__pb2.TickScalarRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__scalar__pb2.TickScalarStreamResponse.FromString,
                )
        self.TickScalarFields = channel.unary_unary(
                '/systemathics.apis.services.tick.v2.TickScalarService/TickScalarFields',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__scalar__pb2.TickScalarFieldsResponse.FromString,
                )
        self.TickScalarAssetProvider = channel.unary_unary(
                '/systemathics.apis.services.tick.v2.TickScalarService/TickScalarAssetProvider',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__scalar__pb2.TickScalarAssetProviderResponse.FromString,
                )


class TickScalarServiceServicer(object):
    """Called to request tick prices data. 
    """

    def TickScalarStream(self, request, context):
        """Gets tick historical data timeseries by identifier using streaming
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TickScalarFields(self, request, context):
        """Gets tick historical data by date
        rpc TickByDate(TickDateRequest) returns (stream GetTickByDateResponse)
        {
        option (google.api.http) = {
        		get: "/v2/tick_date/"
        };
        }

        Gets all available fields by asset and provider.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TickScalarAssetProvider(self, request, context):
        """Gets all available provider by asset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TickScalarServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'TickScalarStream': grpc.unary_stream_rpc_method_handler(
                    servicer.TickScalarStream,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__scalar__pb2.TickScalarRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__scalar__pb2.TickScalarStreamResponse.SerializeToString,
            ),
            'TickScalarFields': grpc.unary_unary_rpc_method_handler(
                    servicer.TickScalarFields,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__scalar__pb2.TickScalarFieldsResponse.SerializeToString,
            ),
            'TickScalarAssetProvider': grpc.unary_unary_rpc_method_handler(
                    servicer.TickScalarAssetProvider,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__scalar__pb2.TickScalarAssetProviderResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'systemathics.apis.services.tick.v2.TickScalarService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TickScalarService(object):
    """Called to request tick prices data. 
    """

    @staticmethod
    def TickScalarStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/systemathics.apis.services.tick.v2.TickScalarService/TickScalarStream',
            systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__scalar__pb2.TickScalarRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__scalar__pb2.TickScalarStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TickScalarFields(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.tick.v2.TickScalarService/TickScalarFields',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__scalar__pb2.TickScalarFieldsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TickScalarAssetProvider(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.tick.v2.TickScalarService/TickScalarAssetProvider',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__scalar__pb2.TickScalarAssetProviderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
