# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/static_data/v1/cache.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from systemathics.apis.type.shared.v1 import asset_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_asset__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5systemathics/apis/services/static_data/v1/cache.proto\x12-systemathics.apis.services.set_static_data.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a,systemathics/apis/type/shared/v1/asset.proto2\x8f\x01\n\x16\x43\x61\x63heStaticDataService\x12u\n\x08SetCache\x12\x32.systemathics.apis.type.shared.v1.AssetTypeRequest\x1a\x16.google.protobuf.Empty\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/staticdata/cache/B\x90\x02\n1com.systemathics.apis.services.set_static_data.v1B\nCacheProtoP\x01\xa2\x02\x04SASS\xaa\x02+Systemathics.Apis.Services.SetStaticData.V1\xca\x02+Systemathics\\Apis\\Services\\SetStaticData\\V1\xe2\x02\x37Systemathics\\Apis\\Services\\SetStaticData\\V1\\GPBMetadata\xea\x02/Systemathics::Apis::Services::SetStaticData::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.static_data.v1.cache_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n1com.systemathics.apis.services.set_static_data.v1B\nCacheProtoP\001\242\002\004SASS\252\002+Systemathics.Apis.Services.SetStaticData.V1\312\002+Systemathics\\Apis\\Services\\SetStaticData\\V1\342\0027Systemathics\\Apis\\Services\\SetStaticData\\V1\\GPBMetadata\352\002/Systemathics::Apis::Services::SetStaticData::V1'
  _globals['_CACHESTATICDATASERVICE'].methods_by_name['SetCache']._options = None
  _globals['_CACHESTATICDATASERVICE'].methods_by_name['SetCache']._serialized_options = b'\202\323\344\223\002\027\022\025/v1/staticdata/cache/'
  _globals['_CACHESTATICDATASERVICE']._serialized_start=210
  _globals['_CACHESTATICDATASERVICE']._serialized_end=353
# @@protoc_insertion_point(module_scope)
