# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from systemathics.apis.services.daily.v2 import set_daily_pb2 as systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2


class SetDailyServiceStub(object):
    """Called to set daily prices data and clear. 
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.WriteDailyScalar = channel.unary_unary(
                '/systemathics.apis.services.daily.v2.SetDailyService/WriteDailyScalar',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyScalarRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.WriteDailyScalarStream = channel.stream_unary(
                '/systemathics.apis.services.daily.v2.SetDailyService/WriteDailyScalarStream',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyScalarStreamRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.WriteDailyVector = channel.unary_unary(
                '/systemathics.apis.services.daily.v2.SetDailyService/WriteDailyVector',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyVectorRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.WriteDailyVectorStream = channel.stream_unary(
                '/systemathics.apis.services.daily.v2.SetDailyService/WriteDailyVectorStream',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyVectorStreamRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateDailyScalar = channel.unary_unary(
                '/systemathics.apis.services.daily.v2.SetDailyService/UpdateDailyScalar',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyScalarRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateDailyScalarStream = channel.stream_unary(
                '/systemathics.apis.services.daily.v2.SetDailyService/UpdateDailyScalarStream',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyScalarStreamRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateDailyVector = channel.unary_unary(
                '/systemathics.apis.services.daily.v2.SetDailyService/UpdateDailyVector',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyVectorRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateDailyVectorStream = channel.stream_unary(
                '/systemathics.apis.services.daily.v2.SetDailyService/UpdateDailyVectorStream',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyVectorStreamRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteDailyScalar = channel.unary_unary(
                '/systemathics.apis.services.daily.v2.SetDailyService/DeleteDailyScalar',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.DeleteDailyScalarRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteDailyVector = channel.unary_unary(
                '/systemathics.apis.services.daily.v2.SetDailyService/DeleteDailyVector',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.DeleteDailyVectorRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class SetDailyServiceServicer(object):
    """Called to set daily prices data and clear. 
    """

    def WriteDailyScalar(self, request, context):
        """Sets daily scalar timeseries.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WriteDailyScalarStream(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WriteDailyVector(self, request, context):
        """Sets daily vector timeseries.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WriteDailyVectorStream(self, request_iterator, context):
        """Sets daily vector timeseries.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDailyScalar(self, request, context):
        """Update daily scalar timeseries.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDailyScalarStream(self, request_iterator, context):
        """Update daily scalar timeseries.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDailyVector(self, request, context):
        """Update daily vectors timeseries.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDailyVectorStream(self, request_iterator, context):
        """Update daily vectors timeseries.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDailyScalar(self, request, context):
        """Delete daily scalar timeseries.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDailyVector(self, request, context):
        """Delete daily scalar timeseries.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SetDailyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'WriteDailyScalar': grpc.unary_unary_rpc_method_handler(
                    servicer.WriteDailyScalar,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyScalarRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'WriteDailyScalarStream': grpc.stream_unary_rpc_method_handler(
                    servicer.WriteDailyScalarStream,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyScalarStreamRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'WriteDailyVector': grpc.unary_unary_rpc_method_handler(
                    servicer.WriteDailyVector,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyVectorRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'WriteDailyVectorStream': grpc.stream_unary_rpc_method_handler(
                    servicer.WriteDailyVectorStream,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyVectorStreamRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateDailyScalar': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDailyScalar,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyScalarRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateDailyScalarStream': grpc.stream_unary_rpc_method_handler(
                    servicer.UpdateDailyScalarStream,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyScalarStreamRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateDailyVector': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDailyVector,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyVectorRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateDailyVectorStream': grpc.stream_unary_rpc_method_handler(
                    servicer.UpdateDailyVectorStream,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyVectorStreamRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteDailyScalar': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDailyScalar,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.DeleteDailyScalarRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteDailyVector': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDailyVector,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.DeleteDailyVectorRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'systemathics.apis.services.daily.v2.SetDailyService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SetDailyService(object):
    """Called to set daily prices data and clear. 
    """

    @staticmethod
    def WriteDailyScalar(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.daily.v2.SetDailyService/WriteDailyScalar',
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyScalarRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WriteDailyScalarStream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/systemathics.apis.services.daily.v2.SetDailyService/WriteDailyScalarStream',
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyScalarStreamRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WriteDailyVector(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.daily.v2.SetDailyService/WriteDailyVector',
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyVectorRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WriteDailyVectorStream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/systemathics.apis.services.daily.v2.SetDailyService/WriteDailyVectorStream',
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyVectorStreamRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDailyScalar(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.daily.v2.SetDailyService/UpdateDailyScalar',
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyScalarRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDailyScalarStream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/systemathics.apis.services.daily.v2.SetDailyService/UpdateDailyScalarStream',
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyScalarStreamRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDailyVector(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.daily.v2.SetDailyService/UpdateDailyVector',
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyVectorRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDailyVectorStream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/systemathics.apis.services.daily.v2.SetDailyService/UpdateDailyVectorStream',
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyVectorStreamRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDailyScalar(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.daily.v2.SetDailyService/DeleteDailyScalar',
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.DeleteDailyScalarRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDailyVector(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.daily.v2.SetDailyService/DeleteDailyVector',
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.DeleteDailyVectorRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
